netapp_ontap.models.storage_availability_zone_space_efficiency_without_snapshots API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_availability_zone_space_efficiency_without_snapshots`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageAvailabilityZoneSpaceEfficiencyWithoutSnapshotsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageAvailabilityZoneSpaceEfficiencyWithoutSnapshots object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ratio: float GET`

    Data reduction ratio (logical_used_without_snapshot / physical_used_without_snapshot)

  `savings: Size GET`

    Space saved by storage efficiencies (logical_used_without_snapshot - physical_used_without_snapshot)